pub struct BandwidthEstimator { /* private fields */ }Expand description
Bandwidth estimator
Implementations
Sourceimpl BandwidthEstimator
impl BandwidthEstimator
Sourcepub fn record_transfer(&mut self, bytes: usize, time_ms: f64)
pub fn record_transfer(&mut self, bytes: usize, time_ms: f64)
Records a transfer
Sourcepub fn record_download(&mut self, bytes: usize, time_ms: f64)
pub fn record_download(&mut self, bytes: usize, time_ms: f64)
Records a download (alias for record_transfer for test compatibility)
Sourcepub const fn estimate(&self) -> f64
pub const fn estimate(&self) -> f64
Estimates current bandwidth (returns bandwidth in bytes per second)
Sourcepub const fn bandwidth_bps(&self) -> f64
pub const fn bandwidth_bps(&self) -> f64
Returns the current bandwidth estimate in bytes per second
Sourcepub fn bandwidth_mbps(&self) -> f64
pub fn bandwidth_mbps(&self) -> f64
Returns the current bandwidth estimate in megabits per second
Sourcepub fn estimate_download_time(&self, bytes: usize) -> f64
pub fn estimate_download_time(&self, bytes: usize) -> f64
Estimates time to download a given size (in milliseconds)
Sourcepub fn is_sufficient_for_quality(&self, quality: StreamingQuality) -> bool
pub fn is_sufficient_for_quality(&self, quality: StreamingQuality) -> bool
Checks if bandwidth is sufficient for quality
Sourcepub fn suggest_quality(&self) -> StreamingQuality
pub fn suggest_quality(&self) -> StreamingQuality
Suggests optimal quality based on bandwidth